McpErrorCodes class

MCP Error codes as defined in the specification

Annotations
  • @immutable

Constructors

McpErrorCodes()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getMessage(int code) String
Get error message for code

Constants

cancelled → const int
internalError → const int
invalidParams → const int
invalidRequest → const int
methodNotFound → const int
networkError → const int
parseError → const int
permissionDenied → const int
promptNotFound → const int
protocolError → const int
rateLimited → const int
resourceNotFound → const int
timeout → const int
toolNotFound → const int