McpMethodAuth class
MCP method authorization configuration
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getRequiredScopes(
String method) → List< String> - Get required scopes for a method
-
requiresAuth(
String method) → bool - Check if method requires authentication
Constants
-
authenticatedMethods
→ const Set<
String> - Methods that require authentication
-
methodScopes
→ const Map<
String, List< String> > - Methods that require specific scopes